@@ -1,9 +1,9 @@
-# SPDX-FileCopyrightText: © 2021 Antonio López Rivera <antonlopezr99@gmail.com>
+# SPDX-FileCopyrightText: © Antonio López Rivera <antonlopezr99@gmail.com>
 # SPDX-License-Identifier: GPL-3.0-only
 
 """
-MPL Plotter: 3D plotting
-------------------------
+3D
+--
 """
 
 from mpl_plotter.three_d.methods import line, scatter, surface, floating_text, \
