@@ -1,3 +1,11 @@
+# SPDX-FileCopyrightText: © Antonio López Rivera <antonlopezr99@gmail.com>
+# SPDX-License-Identifier: GPL-3.0-only
+
+"""
+Plotting Methods
+----------------
+"""
+
 import re
 import inspect
 import warnings
@@ -25,7 +33,7 @@ warnings.filterwarnings("ignore", message="numpy.ufunc size changed")
 class canvas:
 
     def method_backend(self):
-        if not isinstance(self.backend, type(None)):
+        if self.backend is not None:
             try:
                 mpl.use(self.backend)
             except AttributeError:
@@ -37,8 +45,11 @@ class canvas:
     def method_fonts(self):
         """
         Fonts
+        
         Reference:
+
             - https://matplotlib.org/2.0.2/users/customizing.html
+        
         Pyplot method:
             plt.rcParams['<category>.<item>'] = <>
         """
@@ -64,7 +75,7 @@ class canvas:
             self.ax = self.fig.add_subplot(self.shape_and_position, adjustable='box')
 
     def method_figure(self):
-        if not isinstance(self.style, type(None)):
+        if self.style is not None:
             self.plt.style.use(self.style)
         self.fig = self.plt.figure(figsize=self.figsize)
 
@@ -137,8 +148,7 @@ class attributes:
 
             # Colorbar title
             if self.cb_orientation == 'vertical':
-                if not isinstance(self.cb_title,
-                                  type(None)) and self.cb_y_title is False and self.cb_top_title is False:
+                if self.cb_title is not None and not self.cb_y_title and not self.cb_top_title:
                     print('Input colorbar title location with booleans: cb_y_title=True or cb_top_title=True')
                 if self.cb_y_title:
                     cbar.ax.set_ylabel(self.cb_title, rotation=self.cb_title_rotation,
@@ -187,15 +197,15 @@ class attributes:
     def method_resize_axes(self):
 
         # Bound definition
-        if not isinstance(self.x_bounds, type(None)):
-            if not isinstance(self.x_bounds[0], type(None)):
+        if self.x_bounds is not None:
+            if self.x_bounds[0] is not None:
                 self.x_lower_bound = self.x_bounds[0]
-            if not isinstance(self.x_bounds[1], type(None)):
+            if self.x_bounds[1] is not None:
                 self.x_upper_bound = self.x_bounds[1]
-        if not isinstance(self.y_bounds, type(None)):
-            if not isinstance(self.y_bounds[0], type(None)):
+        if self.y_bounds is not None:
+            if self.y_bounds[0] is not None:
                 self.y_lower_bound = self.y_bounds[0]
-            if not isinstance(self.y_bounds[1], type(None)):
+            if self.y_bounds[1] is not None:
                 self.y_upper_bound = self.y_bounds[1]
 
         if self.resize_axes and self.x.size != 0 and self.y.size != 0:
@@ -212,7 +222,7 @@ class attributes:
                     lp = 0
                 # Bounds vector
                 if isinstance(v, type(None)):
-                    v = [self.x_lower_bound, self.x_upper_bound]
+                    v = [l, u]
                 if isinstance(v[0], type(None)):
                     v[0] = l
                 if isinstance(v[1], type(None)):
@@ -234,10 +244,10 @@ class attributes:
 
             # Room to breathe
             if self.demo_pad_plot:
-                pad_x = 0.05 * (abs(self.x + self.x.min()).max() - abs(self.x + self.x.min()).min())
+                pad_x = 0.05 * span(self.x_bounds)
                 self.x_upper_resize_pad = pad_x
                 self.x_lower_resize_pad = pad_x
-                pad_y = 0.05 * (abs(self.y + self.y.min()).max() - abs(self.y + self.y.min()).min())
+                pad_y = 0.05 * span(self.y_bounds)
                 self.y_upper_resize_pad = pad_y
                 self.y_lower_resize_pad = pad_y
 
@@ -263,19 +273,22 @@ class attributes:
                 self.y_upper_resize_pad = self.x_upper_resize_pad
                 self.y_lower_resize_pad = self.x_lower_resize_pad
 
-            # Set bounds
-            self.ax.set_xbound(lower=self.x_bounds[0] - self.x_lower_resize_pad,
-                               upper=self.x_bounds[1] + self.x_upper_resize_pad)
-            self.ax.set_ybound(lower=self.y_bounds[0] - self.y_lower_resize_pad,
-                               upper=self.y_bounds[1] + self.y_upper_resize_pad)
+            # Set bounds ignoring warnings if bounds are equal
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
 
-            self.ax.set_xlim(self.x_bounds[0] - self.x_lower_resize_pad,
-                             self.x_bounds[1] + self.x_upper_resize_pad)
-            self.ax.set_ylim(self.y_bounds[0] - self.y_lower_resize_pad,
-                             self.y_bounds[1] + self.y_upper_resize_pad)
+                self.ax.set_xbound(lower=self.x_bounds[0] - self.x_lower_resize_pad,
+                                   upper=self.x_bounds[1] + self.x_upper_resize_pad)
+                self.ax.set_ybound(lower=self.y_bounds[0] - self.y_lower_resize_pad,
+                                   upper=self.y_bounds[1] + self.y_upper_resize_pad)
+
+                self.ax.set_xlim(self.x_bounds[0] - self.x_lower_resize_pad,
+                                 self.x_bounds[1] + self.x_upper_resize_pad)
+                self.ax.set_ylim(self.y_bounds[0] - self.y_lower_resize_pad,
+                                 self.y_bounds[1] + self.y_upper_resize_pad)
 
             # Aspect ratio
-            if not isinstance(self.aspect, type(None)) and span(self.x_bounds) != 0 and span(self.y_bounds) != 0:
+            if self.aspect is not None and span(self.x_bounds) != 0 and span(self.y_bounds) != 0:
                 y_range = span(self.y_bounds)
                 x_range = span(self.x_bounds)
 
@@ -284,22 +297,22 @@ class attributes:
                 self.ax.set_aspect(aspect)
 
             # Scale
-            if not isinstance(self.scale, type(None)):
+            if self.scale is not None:
                 self.ax.set_aspect(self.scale)
 
     def method_title(self):
-        if not isinstance(self.title, type(None)):
+        if self.title is not None:
             self.ax.set_title(self.title,
                               fontname=self.font if isinstance(self.title_font, type(None)) else self.title_font,
                               weight=self.title_weight,
-                              color=self.title_color if not isinstance(self.title_color, type(None))
-                                    else self.font_color if not isinstance(self.font_color, type(None))
+                              color=self.title_color if self.title_color is not None
+                                    else self.font_color if self.font_color is not None
                                     else self.workspace_color,
                               size=self.title_size + self.font_size_increase)
             self.ax.title.set_position((0.5, self.title_y))
 
     def method_axis_labels(self):
-        if not isinstance(self.x_label, type(None)):
+        if self.x_label is not None:
 
             # Draw label
             self.ax.set_xlabel(self.x_label, fontname=self.font, weight=self.x_label_weight,
@@ -308,10 +321,10 @@ class attributes:
                                rotation=self.x_label_rotation)
 
             # Custom coordinates if provided
-            if not isinstance(self.x_label_coords, type(None)):
+            if self.x_label_coords is not None:
                 self.ax.xaxis.set_label_coords(x=self.x_label_coords[0], y=self.x_label_coords[1])
 
-        if not isinstance(self.y_label, type(None)):
+        if self.y_label is not None:
 
             # y axis label rotation
             if isinstance(self.y_label_rotation, type(None)):
@@ -326,14 +339,14 @@ class attributes:
                                rotation=self.y_label_rotation)
 
             # Custom coordinates if provided
-            if not isinstance(self.y_label_coords, type(None)):
+            if self.y_label_coords is not None:
                 self.ax.yaxis.set_label_coords(x=self.y_label_coords[0], y=self.y_label_coords[1])
 
     def method_spines(self):
         for spine in self.ax.spines.values():
             spine.set_color(self.workspace_color if isinstance(self.spine_color, type(None)) else self.spine_color)
 
-        if not isinstance(self.spines_removed, type(None)):
+        if self.spines_removed is not None:
             for i in range(len(self.spines_removed)):
                 if self.spines_removed[i] == 1:
                     self.ax.spines[["left", "bottom", "top", "right"][i]].set_visible(False)
@@ -352,10 +365,10 @@ class attributes:
         Defaults
         """
         # Fine tick locations
-        if not isinstance(self.y, type(None)):  # Avoid issues with arrays with span 0 (vertical or horizontal lines)
+        if self.y is not None:  # Avoid issues with arrays with span 0 (vertical or horizontal lines)
             if span(self.y) == 0:
                 self.fine_tick_locations = False
-        if not isinstance(self.x, type(None)) and not isinstance(self.y, type(None)):
+        if self.x is not None and self.y is not None:
             if self.fine_tick_locations and self.x.size != 0 and self.y.size != 0:
                 if isinstance(self.x_custom_tick_locations, type(None)):
                     self.x_custom_tick_locations = [self.x.min(), self.x.max()]
@@ -365,38 +378,52 @@ class attributes:
         Checks
         """
         # Custom tick labels
-        if not isinstance(self.x_custom_tick_labels, type(None)):           # Ensure the number of ticks equals the
+        if self.x_custom_tick_labels is not None:                           # Ensure the number of ticks equals the
             if self.x_tick_number != len(self.x_custom_tick_labels):        # length of the list of custom tick
                 self.x_tick_number = len(self.x_custom_tick_labels)         # labels.
         """
         Implementation
         """
-        #   Tick-label distance
+
+        # Tick-label distance
         self.ax.xaxis.set_tick_params(pad=0.1, direction='in')
         self.ax.yaxis.set_tick_params(pad=0.1, direction='in')
-        #   Color
-        if not isinstance(self.tick_color, type(None)):
+
+        # Color
+        if self.tick_color is not None:
             self.ax.tick_params(axis='both', color=self.tick_color)
-        #   Label font and color
+
+        # Label font and color
         for tick in self.ax.get_xticklabels():
             tick.set_fontname(self.font)
             tick.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
         for tick in self.ax.get_yticklabels():
             tick.set_fontname(self.font)
             tick.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
-        #   Label size
-        if not isinstance(self.x_tick_label_size, type(None)):
+
+        # Label size
+        if self.x_tick_label_size is not None:
             self.ax.tick_params(axis='x', labelsize=self.x_tick_label_size + self.font_size_increase)
-        elif not isinstance(self.tick_label_size, type(None)):
+        elif self.tick_label_size is not None:
             self.ax.tick_params(axis='x', labelsize=self.tick_label_size + self.font_size_increase)
-        if not isinstance(self.y_tick_label_size, type(None)):
+        if self.y_tick_label_size is not None:
             self.ax.tick_params(axis='y', labelsize=self.y_tick_label_size + self.font_size_increase)
-        elif not isinstance(self.tick_label_size, type(None)):
+        elif self.tick_label_size is not None:
             self.ax.tick_params(axis='y', labelsize=self.tick_label_size + self.font_size_increase)
-        #   Custom tick positions
-        if not isinstance(self.x_custom_tick_locations, type(None)):
+
+        # Tick locations
+        if isinstance(self.x_custom_tick_locations, type(None)):
+            # No custom tick locations (none provided, fine_tick_locations=False)
+            #   Control over tick number
+            if self.x_tick_number > 1:
+                ticklocs = np.linspace(*self.x_bounds, self.x_tick_number)
+            else:
+                ticklocs = np.array([self.x.mean()])
+            self.ax.set_xticks(ticklocs)
+        else:
+            # Custom tick locations
             high = self.x_custom_tick_locations[0]
-            low = self.x_custom_tick_locations[1]
+            low  = self.x_custom_tick_locations[1]
             # Set usual ticks
             if self.x_tick_number > 1:
                 ticklocs = np.linspace(low, high, self.x_tick_number)
@@ -404,9 +431,18 @@ class attributes:
             else:
                 ticklocs = np.array([low + (high - low)/2])
             self.ax.set_xticks(ticklocs)
-        if not isinstance(self.y_custom_tick_locations, type(None)):
+        if isinstance(self.y_custom_tick_locations, type(None)):
+            # No custom tick locations (none provided, fine_tick_locations=False)
+            #   Control over tick number
+            if self.y_tick_number > 1:
+                ticklocs = np.linspace(*self.y_bounds, self.y_tick_number)
+            else:
+                ticklocs = np.array([self.y.mean()])
+            self.ax.set_yticks(ticklocs)
+        else:
+            # Custom tick locations
             high = self.y_custom_tick_locations[0]
-            low = self.y_custom_tick_locations[1]
+            low  = self.y_custom_tick_locations[1]
             # Set usual ticks
             if self.y_tick_number > 1:
                 ticklocs = np.linspace(low, high, self.y_tick_number)
@@ -414,12 +450,8 @@ class attributes:
             else:
                 ticklocs = np.array([low + (high - low)/2])
             self.ax.set_yticks(ticklocs)
-        #   Prune
-        if not isinstance(self.prune, type(None)):
-            self.ax.xaxis.set_major_locator(self.plt.MaxNLocator(prune=self.prune))
-        if not isinstance(self.prune, type(None)):
-            self.ax.yaxis.set_major_locator(self.plt.MaxNLocator(prune=self.prune))
-        #   Float format
+
+        # Float format
         x_decimals = self.tick_ndecimals if isinstance(self.x_tick_ndecimals, type(None)) \
             else self.x_tick_ndecimals
         y_decimals = self.tick_ndecimals if isinstance(self.y_tick_ndecimals, type(None)) \
@@ -428,33 +460,37 @@ class attributes:
         float_format_y = '%.' + str(y_decimals) + 'f'
         self.ax.xaxis.set_major_formatter(FormatStrFormatter(float_format_x))
         self.ax.yaxis.set_major_formatter(FormatStrFormatter(float_format_y))
-        #   Custom tick labels
-        if not isinstance(self.x_custom_tick_labels, type(None)):
+
+        # Custom tick labels
+        if self.x_custom_tick_labels is not None:
             if len(self.x_custom_tick_labels) == 2 and len(self.x_custom_tick_labels) != self.x_tick_number:
                 self.x_custom_tick_labels = np.linspace(self.x_custom_tick_labels[0],
                                                         self.x_custom_tick_labels[1],
                                                         self.x_tick_number)
             self.ax.set_xticklabels(self.x_custom_tick_labels[::-1])
-        if not isinstance(self.y_custom_tick_labels, type(None)):
+        if self.y_custom_tick_labels is not None:
             if len(self.y_custom_tick_labels) == 2 and len(self.y_custom_tick_labels) != self.y_tick_number:
                 self.y_custom_tick_labels = np.linspace(self.y_custom_tick_labels[0],
                                                         self.y_custom_tick_labels[1],
                                                         self.y_tick_number)
             self.ax.set_yticklabels(self.y_custom_tick_labels[::-1])
-        #       Date tick labels
+
+        # Date tick labels
         if self.x_date_tick_labels:
             fmtd = pd.date_range(start=self.x[0], end=self.x[-1], periods=self.x_tick_number)
             fmtd = [dt.datetime.strftime(d, self.date_format) for d in fmtd]
             self.ax.set_xticklabels(fmtd)
-        #   Tick-label pad ---------------------------------------------------------------------------------------------
-        if not isinstance(self.tick_label_pad, type(None)):
+
+        # Tick-label pad
+        if self.tick_label_pad is not None:
             self.ax.tick_params(axis='both', pad=self.tick_label_pad)
-        #   Rotation
-        if not isinstance(self.x_tick_rotation, type(None)):
+
+        # Rotation
+        if self.x_tick_rotation is not None:
             self.ax.tick_params(axis='x', rotation=self.x_tick_rotation)
             for tick in self.ax.xaxis.get_majorticklabels():
                 tick.set_horizontalalignment("right")
-        if not isinstance(self.y_tick_rotation, type(None)):
+        if self.y_tick_rotation is not None:
             self.ax.tick_params(axis='y', rotation=self.y_tick_rotation)
             for tick in self.ax.yaxis.get_majorticklabels():
                 tick.set_horizontalalignment("left")
@@ -476,10 +512,6 @@ class plot(canvas, attributes):
 
     def run(self):
         self.main()
-        try:
-            self.custom()
-        except AttributeError:
-            pass
         self.finish()
 
     def main(self):
@@ -492,14 +524,17 @@ class plot(canvas, attributes):
 
         # Mock plot
         self.mock()
-
         # Plot
         self.plot()
 
+    def finish(self):
+        # Resize axes
+        self.method_resize_axes()
+        # Legend
+        self.method_legend()
         # Colorbar
         self.method_cb()
 
-    def finish(self):
         # Makeup
         self.method_title()
         self.method_axis_labels()
@@ -520,49 +555,11 @@ class plot(canvas, attributes):
             self.fig.tight_layout()
             self.plt.show()
         else:
-            if self.suppress is False:
+            if not self.suppress:
                 print('Ready for next subplot')
 
 
-class std_input():
-
-    def custom(self):
-        # Resize axes
-        self.method_resize_axes()
-        # Legend
-        self.method_legend()
-
-
-class df_input:
-
-    def method_resize_axes_dataframe(self):
-        if self.resize_axes:
-            xmin = 0
-            ymin = 0
-            xmax = self.z.shape[0]
-            ymax = self.z.shape[1]
-            if isinstance(self.x_upper_bound, type(None)):
-                self.x_upper_bound = xmax
-            if isinstance(self.x_lower_bound, type(None)):
-                self.x_lower_bound = xmin
-            if isinstance(self.y_upper_bound, type(None)):
-                self.y_upper_bound = ymax
-            if isinstance(self.y_lower_bound, type(None)):
-                self.y_lower_bound = ymin
-
-            if not isinstance(self.scale, type(None)):
-                self.ax.set_aspect(self.scale)
-
-            if not isinstance(self.aspect, type(None)):
-                y_range = abs(ymax) + abs(ymin)
-                x_range = abs(xmax) + abs(xmin)
-
-                aspect = x_range/y_range * self.aspect
-
-                self.ax.set_aspect(aspect)
-
-
-class line(plot, std_input):
+class line(plot):
 
     def __init__(self,
                  # Specifics
@@ -574,8 +571,8 @@ class line(plot, std_input):
                  # Fonts
                  font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
-                 fig=None, ax=None, figsize=None, shape_and_position=111, prune=None, resize_axes=True,
-                 scale=None, aspect=None,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
+                 scale=None, aspect=1,
                  # Setup
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
@@ -662,8 +659,8 @@ class line(plot, std_input):
             setattr(self, item, eval(item))
 
         # Ensure x and y are NumPy arrays
-        self.x = ensure_ndarray(self.x) if not isinstance(self.x, type(None)) else None
-        self.y = ensure_ndarray(self.y) if not isinstance(self.y, type(None)) else None
+        self.x = ensure_ndarray(self.x) if self.x is not None else None
+        self.y = ensure_ndarray(self.y) if self.y is not None else None
 
         self.init()
 
@@ -700,11 +697,11 @@ class line(plot, std_input):
                 self.norm = self.y
 
 
-class scatter(plot, std_input):
+class scatter(plot):
 
     def __init__(self,
                  # Specifics
-                 x=None, y=None, point_size=5, marker='o',
+                 x=None, y=None, point_size=5, marker='o', facecolors=None,
                  # Specifics: color
                  color="C0", cmap='RdBu_r', alpha=None, norm=None,
                  # Backend
@@ -712,8 +709,8 @@ class scatter(plot, std_input):
                  # Fonts
                  font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
-                 fig=None, ax=None, figsize=None, shape_and_position=111, prune=None, resize_axes=True,
-                 scale=None, aspect=None,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
+                 scale=None, aspect=1,
                  # Setup
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
@@ -801,20 +798,22 @@ class scatter(plot, std_input):
             setattr(self, item, eval(item))
 
         # Ensure x and y are NumPy arrays
-        self.x = ensure_ndarray(self.x) if not isinstance(self.x, type(None)) else None
-        self.y = ensure_ndarray(self.y) if not isinstance(self.y, type(None)) else None
+        self.x = ensure_ndarray(self.x) if self.x is not None else None
+        self.y = ensure_ndarray(self.y) if self.y is not None else None
 
         self.init()
 
     def plot(self):
 
-        if not isinstance(self.norm, type(None)):
-            self.graph = self.ax.scatter(self.x, self.y, label=self.plot_label, s=self.point_size, marker=self.marker,
+        if self.norm is not None:
+            self.graph = self.ax.scatter(self.x, self.y, label=self.plot_label,
+                                         s=self.point_size, marker=self.marker, facecolors=self.facecolors,
                                          c=self.norm, cmap=self.cmap,
                                          zorder=self.zorder,
                                          alpha=self.alpha)
         else:
-            self.graph = self.ax.scatter(self.x, self.y, label=self.plot_label, s=self.point_size, marker=self.marker,
+            self.graph = self.ax.scatter(self.x, self.y, label=self.plot_label,
+                                         s=self.point_size, marker=self.marker, facecolors=self.facecolors,
                                          color=self.color,
                                          zorder=self.zorder,
                                          alpha=self.alpha)
@@ -825,7 +824,7 @@ class scatter(plot, std_input):
             self.norm = self.y
 
 
-class heatmap(plot, df_input):
+class heatmap(plot):
 
     def __init__(self,
                  # Specifics
@@ -837,8 +836,8 @@ class heatmap(plot, df_input):
                  # Fonts
                  font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
-                 fig=None, ax=None, figsize=None, shape_and_position=111, prune=None, resize_axes=True,
-                 scale=None, aspect=None,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
+                 scale=None, aspect=1,
                  # Setup
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
@@ -926,37 +925,28 @@ class heatmap(plot, df_input):
             setattr(self, item, eval(item))
 
         # Ensure x and y are NumPy arrays
-        self.x = ensure_ndarray(self.x) if not isinstance(self.x, type(None)) else None
-        self.y = ensure_ndarray(self.y) if not isinstance(self.y, type(None)) else None
-        self.z = ensure_ndarray(self.z) if not isinstance(self.z, pd.DataFrame) else self.z if not isinstance(self.z, type(None)) else None
+        self.x = ensure_ndarray(self.x) if self.x is not None else None
+        self.y = ensure_ndarray(self.y) if self.y is not None else None
+        self.z = ensure_ndarray(self.z) if self.z is not None else None
 
         self.init()
 
     def plot(self):
-
-        if not isinstance(self.x, type(None)) and not isinstance(self.y, type(None)):
-            self.graph = self.ax.pcolormesh(self.x, self.y, self.z, cmap=self.cmap,
-                                            zorder=self.zorder,
-                                            alpha=self.alpha,
-                                            label=self.plot_label,
-                                            )
-            # Resize axes
-            self.method_resize_axes()
-
-        else:
-            self.graph = self.ax.pcolormesh(self.z, cmap=self.cmap, norm=self.norm,
-                                            zorder=self.zorder,
-                                            alpha=self.alpha,
-                                            label=self.plot_label, )
-            # Resize axes
-            self.method_resize_axes_dataframe()
+        self.graph = self.ax.pcolormesh(self.x, self.y, self.z, cmap=self.cmap,
+                                        zorder=self.zorder,
+                                        alpha=self.alpha,
+                                        label=self.plot_label,
+                                        shading='auto'
+                                        )
+        # Resize axes
+        self.method_resize_axes()
 
     def mock(self):
         if isinstance(self.x, type(None)) and isinstance(self.y, type(None)):
-            self.z = MockData().waterdropdf()
+            self.x, self.y, self.z = MockData().waterdrop()
 
 
-class quiver(plot, std_input):
+class quiver(plot):
 
     def __init__(self,
                  # Specifics
@@ -969,8 +959,8 @@ class quiver(plot, std_input):
                  # Fonts
                  font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
-                 fig=None, ax=None, figsize=None, shape_and_position=111, prune=None, resize_axes=True,
-                 scale=None, aspect=None,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
+                 scale=None, aspect=1,
                  # Setup
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
@@ -1065,8 +1055,8 @@ class quiver(plot, std_input):
 
 
         # Ensure x and y are NumPy arrays
-        self.x = ensure_ndarray(self.x) if not isinstance(self.x, type(None)) else None
-        self.y = ensure_ndarray(self.y) if not isinstance(self.y, type(None)) else None
+        self.x = ensure_ndarray(self.x) if self.x is not None else None
+        self.y = ensure_ndarray(self.y) if self.y is not None else None
         self.init()
 
     def plot(self):
@@ -1112,7 +1102,7 @@ class quiver(plot, std_input):
         self.color = cmap(c)
 
 
-class streamline(plot, std_input):
+class streamline(plot):
 
     def __init__(self,
                  # Specifics
@@ -1124,8 +1114,8 @@ class streamline(plot, std_input):
                  # Fonts
                  font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
-                 fig=None, ax=None, figsize=None, shape_and_position=111, prune=None, resize_axes=True,
-                 scale=None, aspect=None,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
+                 scale=None, aspect=1,
                  # Setup
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
@@ -1216,10 +1206,10 @@ class streamline(plot, std_input):
             setattr(self, item, eval(item))
 
         # Ensure x and y are NumPy arrays
-        self.x = ensure_ndarray(self.x) if not isinstance(self.x, type(None)) else None
-        self.y = ensure_ndarray(self.y) if not isinstance(self.y, type(None)) else None
-        self.u = ensure_ndarray(self.u) if not isinstance(self.u, type(None)) else None
-        self.v = ensure_ndarray(self.v) if not isinstance(self.v, type(None)) else None
+        self.x = ensure_ndarray(self.x) if self.x is not None else None
+        self.y = ensure_ndarray(self.y) if self.y is not None else None
+        self.u = ensure_ndarray(self.u) if self.u is not None else None
+        self.v = ensure_ndarray(self.v) if self.v is not None else None
 
         self.init()
 
@@ -1252,7 +1242,7 @@ class streamline(plot, std_input):
             self.color = rule_color(self.u)
 
 
-class fill_area(plot, std_input):
+class fill_area(plot):
 
     def __init__(self,
                  # Specifics
@@ -1264,8 +1254,8 @@ class fill_area(plot, std_input):
                  # Fonts
                  font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
-                 fig=None, ax=None, figsize=None, shape_and_position=111, prune=None, resize_axes=True,
-                 scale=None, aspect=None,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
+                 scale=None, aspect=1,
                  # Setup
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
@@ -1359,9 +1349,9 @@ class fill_area(plot, std_input):
             setattr(self, item, eval(item))
 
         # Ensure x and y are NumPy arrays
-        self.x = ensure_ndarray(self.x) if not isinstance(self.x, type(None)) else None
-        self.y = ensure_ndarray(self.y) if not isinstance(self.y, type(None)) else None
-        self.z = ensure_ndarray(self.z) if not isinstance(self.z, type(None)) else None
+        self.x = ensure_ndarray(self.x) if self.x is not None else None
+        self.y = ensure_ndarray(self.y) if self.y is not None else None
+        self.z = ensure_ndarray(self.z) if self.z is not None else None
 
         self.init()
 
@@ -1370,7 +1360,7 @@ class fill_area(plot, std_input):
         """
         Fill the region below the intersection of S and Z
         """
-        if not isinstance(self.z, type(None)):
+        if self.z is not None:
             if self.between:
                 self.ax.fill_between(self.x, self.y, self.z, facecolor=self.color,
                                      alpha=self.alpha, label=self.plot_label)
@@ -1380,7 +1370,7 @@ class fill_area(plot, std_input):
             if self.above:
                 self.ax.fill_between(self.x, self.i_above(), np.zeros(self.y.shape), facecolor=self.color,
                                      alpha=self.alpha, label=self.plot_label)
-            if self.between is False and self.below is False and self.above is False:
+            if not self.between and not self.below and not self.above:
                 print_color('No area chosen to fill: specify whether to fill "between", "below" or "above" the curves',
                             'grey')
         else:
@@ -1408,10 +1398,12 @@ class fill_area(plot, std_input):
             self.x = np.arange(-6, 6, .01)
             self.y = MockData().boltzman(self.x, 0, 1)
             self.z = 1 - MockData().boltzman(self.x, 0.5, 1)
-            line(fig=self.fig, ax=self.ax, x=self.x, y=self.y, color='darkred', line_width=2, grid=not self.grid,
-                 plot_label=None, backend=self.backend)
-            line(fig=self.fig, ax=self.ax, x=self.x, y=self.z, color='darkred', line_width=2, grid=not self.grid,
-                 plot_label=None, backend=self.backend)
+            line(x=self.x, y=self.y,
+                 grid=False, resize_axes=False,
+                 ax=self.ax, fig=self.fig)
+            line(x=self.x, y=self.z,
+                 grid=False, resize_axes=False,
+                 ax=self.ax, fig=self.fig)
             self.below = True
 
 
